# API URLS
API_BASE_URL = "https://businessspecificapimanglobal.azure-api.net/"
API_AUTH_PATH = "old-authorization/incharge-api/user/token"
API_GET_STATIONS_PATH = "station-configuration/pub/stations"
API_GET_STATION_CONSUMPTION_PATH = "energy-consumptions/pub/consumption/"

# API HEADERS
API_AUTH_SUB_KEY_HEADER = {
    "Ocp-Apim-Subscription-Key": "15dd233179974ff6aa63dc8ae2499a1b"
}
API_ENDPOINT_SUB_KEY_HEADER = {
    "Ocp-Apim-Subscription-Key": "7685786eb9544d97923b0f01ac1b45d8"
}
API_REFERER_HEADER = {"Referer": "https://myincharge.vattenfall.com/"}
API_ACCEPT_HEADER = {"Accept": "application/vnd.vattenfall.v1.comboChart+json"}
